TaskAttribute

Enum TaskAttribute 

pub enum TaskAttribute {
    Untagged,
    Simple,
    Ordered,
    HeadOfQueue,
    ACA,
    Reserved(u8),
}
SCSI Task Attributes for command ordering and queuing

Defines how SCSI commands should be queued and executed relative to other commands. These attributes control the ordering behavior of commands in the target’s command queue.

Variants



Untagged

Untagged command (0) - legacy simple queuing



Simple

Simple task attribute (1) - commands may be reordered for optimization



Ordered

Ordered task attribute (2) - commands must execute in order



HeadOfQueue

Head of queue task attribute (3) - command should execute immediately



ACA

Auto Contingent Allegiance (4) - special error recovery attribute



Reserved(u8)

Reserved attribute values (5-7) - future use