pub struct RawScsiCmdRespFlags(/* private fields */);Expand description
Represents the wire format for the flags in a SCSI Command Response PDU.
Implementations
Sourceimpl RawScsiCmdRespFlags
impl RawScsiCmdRespFlags
Sourcepub const O_SMALL: u8 = 0b0001_0000
pub const O_SMALL: u8 = 0b0001_0000
Bitmask for the bidirectional read residual underflow flag.
Sourcepub fn set_o_small(&mut self, on: bool)
pub fn set_o_small(&mut self, on: bool)
Sets or clears the bidirectional read residual overflow flag.
Sourcepub fn set_u_small(&mut self, on: bool)
pub fn set_u_small(&mut self, on: bool)
Sets or clears the bidirectional read residual underflow flag.